"""
1999- Nineteen Ninty Nine
1888 - Eighteen Eighty Eight
1777 - Seventeen Seventy Seven
1111 - Oneeen Onety One

Not fully huristics
"""

from num2words import num2words

def spell(N):
    if N // 1_0000 ==0:
        N = divmod(N, 100)
        top, bot = N[0], N[1]

        result = [ ]

        if top == 11:
            result.append("OneTeen")
        elif top == 12:
            result.append("TwoTeen")

        else:
            result.append(num2words(top))


        botx, boty = divmod(bot, 10)

        if botx == 1:
            result.append("Onety")
            result.append(num2words(boty))

        else:
            result.append(num2words(bot))

        return ' '.join(result)




from importlib import resources  # Python 3.7+
import sys

from nosai import numbers

def main():
    # If a number is given as argument
    if len(sys.argv) == 1:
        print(numbers.spell(sys.argv[1]))
      
    elif len(sys.argv) > 1:
        print("Please enter only one number as argument")
      
    else:
        print("Enter the number as a argument")
        
        
if __name__ == "__main__":
    main()
